@@ -17,7 +17,9 @@
 #' )
 #' pars_terms(term)
 pars_terms <- function(x, scalar = NULL, ...) {
-  chkor(is_term(x), is_term_rcrd(x))
+  if(!vld_s3_class(x, "term") && !vld_s3_class(x, "term_rcrd")) {
+    chkor_vld(vld_s3_class(x, "term"), vld_s3_class(x, "term_rcrd"))
+  }
   if(!missing(scalar)) {
     deprecate_soft("0.2.1", "term::pars_terms(scalar =)")
   }
